@@ -55,6 +55,16 @@ namespace anyks {
 		letter,  // Флаг проверки легальности буквы
 		similars // Флаг проверки смешанных букв разных словарей
 	};
+	// Основные опции
+	enum class options_t : u_short {
+		debug,     // Флаг режима отладки
+		stress,    // Флаг разрешения использовать символы ударения
+		uppers,    // Флаг разрешения проставлять регистры букв в словах
+		collect,   // Флаг разрешения сборку суффиксов цифровых аббревиатур
+		onlyGood,  // Флаг использования только слов из белого списка
+		mixdicts,  // Флаг разрешающий детектировать слова из смешанных словарей
+		confidence // Флаг разрешающий загружать n-граммы из arpa так-как они есть
+	};
 	// Флаги соответствия
 	enum class match_t : u_int {
 		url,      // Флаг проверки соответствия слова url адресу
@@ -88,14 +98,14 @@ namespace anyks {
 		 */
 		void allowStress() noexcept {
 			// Разрешаем использовать ударение в словах
-			tokenizer.allowStress();
+			tokenizer.setOption(tokenizer_t::options_t::stress);
 		}
 		/**
 		 * disallowStress Метод запрещения использовать ударение в словах
 		 */
 		void disallowStress() noexcept {
 			// Запрещаем использовать ударение в словах
-			tokenizer.disallowStress();
+			tokenizer.unsetOption(tokenizer_t::options_t::stress);
 		}
 		/**
 		 * idt Метод извлечения идентификатора токена
@@ -115,12 +125,53 @@ namespace anyks {
 			alphabet.setzone(zone);
 		}
 		/**
-		 * setAbbr Метод добавления аббревиатуры
+		 * addAbbr Метод добавления аббревиатуры
+		 * @param idw идентификатор слова для добавления
+		 */
+		void addAbbr(const size_t idw) noexcept {
+			// Добавляем аббревиатуру
+			tokenizer.addAbbr(idw);
+		}
+		/**
+		 * addAbbr Метод добавления аббревиатуры
 		 * @param word слово для добавления
 		 */
-		void setAbbr(const wstring & word) noexcept {
-			// Устанавливаем аббревиатуру
-			tokenizer.setAbbr(word);
+		void addAbbr(const wstring & word) noexcept {
+			// Добавляем аббревиатуру
+			tokenizer.addAbbr(word);
+		}
+		/**
+		 * setAbbrs Метод установки списка аббревиатур
+		 * @param abbrs список аббревиатур
+		 */
+		void setAbbrs(const set <size_t> & abbrs) noexcept {
+			// Устанавливаем список аббревиатур
+			tokenizer.setAbbrs(abbrs);
+		}
+		/**
+		 * addSuffix Метод установки суффикса цифровой аббревиатуры
+		 * @param idw идентификатор суффикса цифровой аббревиатуры
+		 */
+		void addSuffix(const size_t idw) noexcept {
+			// Устанавливаем идентификатор суффикса цифровой аббревиатуры
+			tokenizer.addSuffix(idw);
+		}
+		/**
+		 * setSuffixes Метод установки списка суффиксов цифровых аббревиатур
+		 * @param suffix список суффиксов цифровых аббревиатур
+		 */
+		void setSuffixes(const set <size_t> & suffix) noexcept {
+			// Устанавливаем список суффиксов цифровых аббревиатур
+			tokenizer.setSuffixes(suffix);
+		}
+		/**
+		 * addSuffix Метод извлечения суффикса из цифровой аббревиатуры
+		 * @param word слово для извлечения суффикса аббревиатуры
+		 * @param idw  идентификатор обрабатываемого слова
+		 */
+		void addSuffix(const wstring & word, const size_t idw = idw_t::NIDW) noexcept {
+			// Устанавливаем суффикс цифровой аббревиатуры
+			tokenizer.addSuffix(word, idw);
 		}
 		/**
 		 * setAlphabet Метод установки алфавита
@@ -193,9 +244,29 @@ namespace anyks {
 		 * setOption Метод установки опций модуля
 		 * @param option опция для установки
 		 */
-		void setOption(const alm_t::options_t option) noexcept {
-			// Выполняем установку опций модуля
-			alm->setOption(option);
+		void setOption(const options_t option) noexcept {
+			// Устанавливаем нужный нам тип настроек
+			switch((u_short) option){
+				// Если включён режим отладки
+				case (u_short) options_t::debug: {
+					// Выполняем установку опций модуля
+					alm->setOption(alm_t::options_t::debug);
+					// Устанавливаем режим отладки для токенизатора
+					tokenizer.setOption(tokenizer_t::options_t::debug);
+				} break;
+				// Устанавливаем флаг использования только слов из белого списка
+				case (u_short) options_t::onlyGood: alm->setOption(alm_t::options_t::onlyGood); break;
+				// Устанавливаем флаг разрешающий детектировать слова из смешанных словарей
+				case (u_short) options_t::mixdicts: alm->setOption(alm_t::options_t::mixdicts); break;
+				// Устанавливаем флаг разрешающий загружать n-граммы из arpa так-как они есть
+				case (u_short) options_t::confidence: alm->setOption(alm_t::options_t::confidence); break;
+				// Устанавливаем флаг разрешения использовать символы ударения
+				case (u_short) options_t::stress: tokenizer.setOption(tokenizer_t::options_t::stress); break;
+				// Устанавливаем флаг разрешения проставлять регистры букв в словах
+				case (u_short) options_t::uppers: tokenizer.setOption(tokenizer_t::options_t::uppers); break;
+				// Устанавливаем флаг разрешения сборку суффиксов цифровых аббревиатур
+				case (u_short) options_t::collect: tokenizer.setOption(tokenizer_t::options_t::collect); break;
+			}
 		}
 		/**
 		 * getUnknown Метод извлечения неизвестного слова
@@ -250,9 +321,29 @@ namespace anyks {
 		 * unsetOption Метод отключения опции модуля
 		 * @param option опция для отключения
 		 */
-		void unsetOption(const alm_t::options_t option) noexcept {
-			// Выполняем отключение опции модуля
-			alm->unsetOption(option);
+		void unsetOption(const options_t option) noexcept {
+			// Выполняем отключение нужный нам тип настроек
+			switch((u_short) option){
+				// Если включён режим отладки
+				case (u_short) options_t::debug: {
+					// Выполняем установку опций модуля
+					alm->unsetOption(alm_t::options_t::debug);
+					// Выполняем отключение режим отладки для токенизатора
+					tokenizer.unsetOption(tokenizer_t::options_t::debug);
+				} break;
+				// Выполняем отключение флаг использования только слов из белого списка
+				case (u_short) options_t::onlyGood: alm->unsetOption(alm_t::options_t::onlyGood); break;
+				// Выполняем отключение флаг разрешающий детектировать слова из смешанных словарей
+				case (u_short) options_t::mixdicts: alm->unsetOption(alm_t::options_t::mixdicts); break;
+				// Выполняем отключение флаг разрешающий загружать n-граммы из arpa так-как они есть
+				case (u_short) options_t::confidence: alm->unsetOption(alm_t::options_t::confidence); break;
+				// Выполняем отключение флаг разрешения использовать символы ударения
+				case (u_short) options_t::stress: tokenizer.unsetOption(tokenizer_t::options_t::stress); break;
+				// Выполняем отключение флаг разрешения проставлять регистры букв в словах
+				case (u_short) options_t::uppers: tokenizer.unsetOption(tokenizer_t::options_t::uppers); break;
+				// Выполняем отключение флаг разрешения сборку суффиксов цифровых аббревиатур
+				case (u_short) options_t::collect: tokenizer.unsetOption(tokenizer_t::options_t::collect); break;
+			}
 		}
 		/**
 		 * getBadwords Метод извлечения чёрного списка
@@ -427,6 +518,51 @@ namespace anyks {
 			// Выводрим результат проверки
 			return alphabet.isAllowApostrophe();
 		}
+		/**
+		 * isToken Метод проверки идентификатора на токен
+		 * @param idw идентификатор слова для проверки
+		 * @return    результат проверки
+		 */
+		const bool isToken(const size_t idw) noexcept {
+			// Выполняем проверку на токен
+			return tokenizer.isToken(idw);
+		}
+		/**
+		 * isIdWord Метод проверки на соответствие идентификатора слову
+		 * @param idw идентификатор слова для проверки
+		 * @return    результат проверки идентификатора
+		 */
+		const bool isIdWord(const size_t idw) noexcept {
+			// Выполняем проверку на соответствие токена разрешённому слову
+			return tokenizer.isIdWord(idw);
+		}
+		/**
+		 * isAbbr Метод проверки слова на соответствие аббревиатуры
+		 * @param idw идентификатор слова для проверки
+		 * @return    результат проверки
+		 */
+		const bool isAbbr(const size_t idw) noexcept {
+			// Выводим результат проверки на аббревиатуру
+			return tokenizer.isAbbr(idw);
+		}
+		/**
+		 * isAbbr Метод проверки слова на соответствие аббревиатуры
+		 * @param  word слово для проверки
+		 * @return      результат проверки
+		 */
+		const bool isAbbr(const wstring & word) noexcept {
+			// Выводим результат проверки на аббревиатуру
+			return tokenizer.isAbbr(word);
+		}
+		/**
+		 * isSuffix Метод проверки слова на суффикс цифровой аббревиатуры
+		 * @param  word слово для проверки
+		 * @return      результат проверки
+		 */
+		const bool isSuffix(const wstring & word) noexcept {
+			// Выводим результат проверки на суффикс цифровой аббревиатуры
+			return tokenizer.isSuffix(word);
+		}
 		/**
 		 * getUserTokenId Метод получения идентификатора пользовательского токена
 		 * @param name слово для которого нужно получить идентификатор
@@ -1001,6 +1137,66 @@ namespace anyks {
 			// Выполняем проверку существования последовательности
 			return alm->check(text, accurate);
 		}
+		/**
+		 * checkSequence Метод проверки существования последовательности, с указанным шагом
+		 * @param text текст для проверки существования
+		 * @param step размер шага проверки последовательности
+		 * @return     результат проверки
+		 */
+		const bool checkSequence(const wstring & text, const u_short step) noexcept {
+			// Выполняем проверку существования последовательности
+			return alm->check(text, step);
+		}
+		/**
+		 * checkSequence Метод проверки существования последовательности, с указанным шагом
+		 * @param seq  список слов последовательности
+		 * @param step размер шага проверки последовательности
+		 * @return     результат проверки
+		 */
+		const bool checkSequence(const vector <wstring> & seq, const u_short step) noexcept {
+			// Выполняем проверку существования последовательности
+			return alm->check(seq, step);
+		}
+		/**
+		 * checkSequence Метод проверки существования последовательности, с указанным шагом
+		 * @param seq  список слов последовательности
+		 * @param step размер шага проверки последовательности
+		 * @return     результат проверки
+		 */
+		const bool checkSequence(const vector <size_t> & seq, const u_short step) noexcept {
+			// Выполняем проверку существования последовательности
+			return alm->check(seq, step);
+		}
+		/**
+		 * existSequence Метод проверки существования последовательности, с указанным шагом
+		 * @param text текст для проверки существования
+		 * @param step размер шага проверки последовательности
+		 * @return     результат проверки
+		 */
+		const pair <bool, size_t> existSequence(const wstring & text, const u_short step) noexcept {
+			// Выполняем проверку существования последовательности
+			return alm->exist(text, step);
+		}
+		/**
+		 * existSequence Метод проверки существования последовательности, с указанным шагом
+		 * @param seq  список слов последовательности
+		 * @param step размер шага проверки последовательности
+		 * @return     результат проверки
+		 */
+		const pair <bool, size_t> existSequence(const vector <wstring> & seq, const u_short step) noexcept {
+			// Выполняем проверку существования последовательности
+			return alm->exist(seq, step);
+		}
+		/**
+		 * existSequence Метод проверки существования последовательности, с указанным шагом
+		 * @param seq  список слов последовательности
+		 * @param step размер шага проверки последовательности
+		 * @return     результат проверки
+		 */
+		const pair <bool, size_t> existSequence(const vector <size_t> & seq, const u_short step) noexcept {
+			// Выполняем проверку существования последовательности
+			return alm->exist(seq, step);
+		}
 		/**
 		 * check Метод проверки строки
 		 * @param str  строка для проверки
@@ -1039,6 +1235,8 @@ namespace anyks {
 			switch(u_short(flag)){
 				// Выполняем проверку на соответствие слова url адресу
 				case u_short(match_t::url): return alphabet.isUrl(tmp);
+				// Выполняем проверку на соответствие слова аббревиатуре
+				case u_short(match_t::abbr): return tokenizer.isAbbr(tmp);
 				// Выполняем проверку является ли строка латиницей
 				case u_short(match_t::latian): return alphabet.isLatian(tmp);
 				// Выполняем проверку на соответствие слова числу
@@ -1061,8 +1259,6 @@ namespace anyks {
 				case u_short(match_t::special): return alphabet.isSpecial(tmp.front());
 				// Выполняем проверку является ли буква символом изоляции
 				case u_short(match_t::isolation): return alphabet.isIsolation(tmp.front());
-				// Выполняем проверку на соответствие слова аббревиатуре
-				case u_short(match_t::abbr): return (tokenizer.isAbbr(tmp) || alphabet.isAbbr(tmp));
 			}
 			// Выводим результат по умолчанию
 			return false;
@@ -1220,11 +1416,14 @@ PYBIND11_MODULE(alm, m) {
 	.value("isolation", anyks::match_t::isolation)
 	.export_values();
 	// Список флагов основных опций библиотеки
-	py::enum_ <anyks::alm_t::options_t> (m, "options_t")
-	.value("debug", anyks::alm_t::options_t::debug)
-	.value("onlyGood", anyks::alm_t::options_t::onlyGood)
-	.value("mixdicts", anyks::alm_t::options_t::mixdicts)
-	.value("confidence", anyks::alm_t::options_t::confidence)
+	py::enum_ <anyks::options_t> (m, "options_t")
+	.value("debug", anyks::options_t::debug)
+	.value("stress", anyks::options_t::stress)
+	.value("uppers", anyks::options_t::uppers)
+	.value("collect", anyks::options_t::collect)
+	.value("onlyGood", anyks::options_t::onlyGood)
+	.value("mixdicts", anyks::options_t::mixdicts)
+	.value("confidence", anyks::options_t::confidence)
 	.export_values();
 	// Структура параметров расчёта перплексии
 	py::class_ <anyks::alm_t::ppl_t> (m, "ppl_t")
@@ -1246,14 +1445,14 @@ PYBIND11_MODULE(alm, m) {
 		.def("ids", &anyks::Methods::ids, "Sequence ID retrieval method")
 		// setZone Метод установки пользовательской зоны
 		.def("setZone", &anyks::Methods::setZone, "User zone set method")
-		// setAbbr Метод добавления аббревиатуры
-		.def("setAbbr", &anyks::Methods::setAbbr, "Method set abbreviation")
 		// setAlphabet Метод установки алфавита
 		.def("setAlphabet", &anyks::Methods::setAlphabet, "Method set Alphabet")
 		// setUnknown Метод установки неизвестного слова
 		.def("setUnknown", &anyks::Methods::setUnknown, "Method set unknown word")
 		// getName Метод извлечения названия библиотеки
 		.def("getName", &anyks::Methods::getName, "Library name retrieval method")
+		// isToken Метод проверки идентификатора на токен
+		.def("isToken", &anyks::Methods::isToken, "Checking a word against a token")
 		// sentences Метод генерации предложений
 		.def("sentences", &anyks::Methods::sentences, "Sentences generation method")
 		// getEmail Метод извлечения электронной почты автора
@@ -1264,7 +1463,9 @@ PYBIND11_MODULE(alm, m) {
 		.def("getAuthor", &anyks::Methods::getAuthor, "Author name retrieval method")
 		// find Метод поиска n-грамм в тексте
 		.def("findNgram", &anyks::Methods::findNgram, "N-gram search method in text")
-		// setOption Метод установки опций модуля
+		// isIdWord Метод проверки на соответствие идентификатора слову
+		.def("isIdWord", &anyks::Methods::isIdWord, "Checking a token against a word")
+		// setOption Метод установки опций модуля языковой модели
 		.def("setOption", &anyks::Methods::setOption, "Method for set module options")
 		// getUnknown Метод извлечения неизвестного слова
 		.def("getUnknown", &anyks::Methods::getUnknown, "Method extraction unknown word")
@@ -1355,8 +1556,12 @@ PYBIND11_MODULE(alm, m) {
 		// switchAllowApostrophe Метод разрешения или запрещения апострофа как части слова
 		.def("switchAllowApostrophe", &anyks::Methods::switchAllowApostrophe, "Method for permitting or denying an apostrophe as part of a word");
 	} {
+		// addAbbr Метод добавления аббревиатуры в виде идентификатора
+		m.def("addAbbr", overload_cast_ <const size_t> ()(&anyks::Methods::addAbbr), "Method add abbreviation")
+		// addAbbr Метод добавления аббревиатуры в виде слова
+		.def("addAbbr", overload_cast_ <const wstring &> ()(&anyks::Methods::addAbbr), "Method add abbreviation")
 		// addBadword Метод добавления похого слова в список
-		m.def("addBadword", overload_cast_ <const wstring &> ()(&anyks::Methods::addBadword), "Method add bad word")
+		.def("addBadword", overload_cast_ <const wstring &> ()(&anyks::Methods::addBadword), "Method add bad word")
 		// addGoodIdw Метод добавления идентификатора похого слова в список
 		.def("addBadword", overload_cast_ <const size_t> ()(&anyks::Methods::addBadword), "Method add bad idw word")
 		// perplexity Метод расчёта перплексии текста
@@ -1365,12 +1570,20 @@ PYBIND11_MODULE(alm, m) {
 		.def("addGoodword", overload_cast_ <const wstring &> ()(&anyks::Methods::addGoodword), "Method add good word")
 		// addGoodword Метод добавления хорошего слова в список
 		.def("addGoodword", overload_cast_ <const size_t> ()(&anyks::Methods::addGoodword), "Method add good idw word")
+		// setAbbrs Метод установки списка идентификаторов аббревиатур
+		.def("setAbbrs", overload_cast_ <const set <size_t> &> ()(&anyks::Methods::setAbbrs), "Method set abbreviations")
+		// isAbbr Метод проверки слова на соответствие аббревиатуры
+		.def("isAbbr", overload_cast_ <const size_t> ()(&anyks::Methods::isAbbr), "Checking a word against a abbreviation")
 		// countBigrams Метод проверки количества найденных биграмм
 		.def("countBigrams", overload_cast_ <const wstring &> ()(&anyks::Methods::countBigrams), "Method get count bigrams")
 		// perplexity Метод расчёта перплексии текста
 		.def("perplexity", overload_cast_ <const vector <size_t> &> ()(&anyks::Methods::perplexity), "Perplexity calculation")
+		// isAbbr Метод проверки слова на соответствие аббревиатуры
+		.def("isAbbr", overload_cast_ <const wstring &> ()(&anyks::Methods::isAbbr), "Checking a word against a abbreviation")
 		// countTrigrams Метод проверки количества найденных триграмм
 		.def("countTrigrams", overload_cast_ <const wstring &> ()(&anyks::Methods::countTrigrams), "Method get count trigrams")
+		// Метод добавления идентификатора суффикса цифровой аббреувиатуры
+		.def("addSuffix", overload_cast_ <const size_t> ()(&anyks::Methods::addSuffix), "Method add number suffix abbreviation")
 		// countGrams Метод проверки количества найденных n-грамм
 		.def("countGrams", overload_cast_ <const wstring &> ()(&anyks::Methods::countGrams), "Method get count N-gram by lm size")
 		// countBigrams Метод проверки количества найденных биграмм
@@ -1391,6 +1604,10 @@ PYBIND11_MODULE(alm, m) {
 		.def("setGoodwords", overload_cast_ <const vector <wstring> &> ()(&anyks::Methods::setGoodwords), "Method set words to whitelist")
 		// countGrams Метод проверки количества найденных n-грамм
 		.def("countGrams", overload_cast_ <const vector <size_t> &> ()(&anyks::Methods::countGrams), "Method get count N-gram by lm size")
+		// setSuffixes Метод установки списка идентификаторов аббревиатур
+		.def("setSuffixes", overload_cast_ <const set <size_t> &> ()(&anyks::Methods::setSuffixes), "Method set number suffix abbreviations")
+		// isSuffix Метод проверки слова на суффикс цифровой аббревиатуры
+		.def("isSuffix", overload_cast_ <const wstring &> ()(&anyks::Methods::isSuffix), "Checking a word against a number suffix abbreviation")
 		// getUppers Метод извлечения регистров для каждого слова
 		.def("getUppers", overload_cast_ <const vector <size_t> &> ()(&anyks::Methods::getUppers), "Method for extracting registers for each word");
 	} {
@@ -1413,6 +1630,10 @@ PYBIND11_MODULE(alm, m) {
 		// pplByFiles Метод чтения расчёта перплексии по файлу или группе файлов
 		.def("pplByFiles", &anyks::Methods::pplByFiles, "Method for reading perplexity calculation by file or group of files", py::arg("path") = L"", py::arg("ext") = L"txt")
 		// checkSequence Метод проверки существования последовательности
+		.def("checkSequence", overload_cast_ <const wstring &, const u_short> ()(&anyks::Methods::checkSequence), "Sequence Existence Method", py::arg("text") = L"", py::arg("step") = 2)
+		// existSequence Метод проверки существования последовательности, без учёта токенов не являющимися словами
+		.def("existSequence", overload_cast_ <const wstring &, const u_short> ()(&anyks::Methods::existSequence), "Sequence Existence Method", py::arg("text") = L"", py::arg("step") = 2)
+		// checkSequence Метод проверки существования последовательности
 		.def("checkSequence", overload_cast_ <const wstring &, const bool> ()(&anyks::Methods::checkSequence), "Sequence Existence Method", py::arg("text") = L"", py::arg("accurate") = false)
 		// check Метод проверки строки
 		.def("check", overload_cast_ <const wstring &, const anyks::check_t> ()(&anyks::Methods::check), "String Check Method", py::arg("str") = L"", py::arg("flag") = anyks::check_t::letter)
@@ -1422,6 +1643,16 @@ PYBIND11_MODULE(alm, m) {
 		.def("sentencesToFile", &anyks::Methods::sentencesToFile, "Method for assembling a specified number of sentences and writing to a file", py::arg("counts") = 0, py::arg("filename") = L"")
 		// fixUppersByFiles Метод исправления регистров текста в текстовом файле
 		.def("fixUppersByFiles", &anyks::Methods::fixUppersByFiles, "Method for correcting text registers in a text file", py::arg("path") = L"", py::arg("filename") = L"", py::arg("ext") = L"txt")
+		// Метод добавления идентификатора суффикса цифровой аббреувиатуры
+		.def("addSuffix", overload_cast_ <const wstring &, const size_t> ()(&anyks::Methods::addSuffix), "Method add number suffix abbreviation", py::arg("word") = L"", py::arg("idw") = anyks::idw_t::NIDW)
+		// checkSequence Метод проверки существования последовательности
+		.def("checkSequence", overload_cast_ <const vector <size_t> &, const u_short> ()(&anyks::Methods::checkSequence), "Sequence Existence Method", py::arg("seq") = vector <size_t> (), py::arg("step") = 2)
+		// checkSequence Метод проверки существования последовательности, без учёта токенов не являющимися словами
+		.def("existSequence", overload_cast_ <const vector <size_t> &, const u_short> ()(&anyks::Methods::existSequence), "Sequence Existence Method", py::arg("seq") = vector <size_t> (), py::arg("step") = 2)
+		// checkSequence Метод проверки существования последовательности
+		.def("checkSequence", overload_cast_ <const vector <wstring> &, const u_short> ()(&anyks::Methods::checkSequence), "Sequence Existence Method", py::arg("seq") = vector <wstring> (), py::arg("step") = 2)
+		// checkSequence Метод проверки существования последовательности, без учёта токенов не являющимися словами
+		.def("existSequence", overload_cast_ <const vector <wstring> &, const u_short> ()(&anyks::Methods::existSequence), "Sequence Existence Method", py::arg("seq") = vector <wstring> (), py::arg("step") = 2)
 		// delInText Метод очистки текста
 		.def("delInText", overload_cast_ <const wstring &, const anyks::wdel_t> ()(&anyks::Methods::delInText), "Method for delete letter in text", py::arg("text") = L"", py::arg("flag") = anyks::wdel_t::broken)
 		// checkSequence Метод проверки существования последовательности
